package cn.estsh.i3plus.pojo.wms.sqlpack;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.HqlPack;
import cn.estsh.i3plus.pojo.base.tool.SqlPack;
import cn.estsh.i3plus.pojo.wms.bean.*;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description : 仓库管理对象封装
 * @Reference :
 * @Author : silliter.yuan
 * @CreateDate : 2018-10-31 10:45
 * @Modify:
 **/
public class WmsHqlPack {

    /**
     * 封装公用查询参数
     * @param bean 实体对象
     * @param hqlStr 查询语句
     * @return 封装完成的查询语句
     */
    public static String getStringBuilderPack(BaseBean bean, StringBuffer hqlStr) {

        // 判断工厂代码是否为空
        if (StringUtils.isNotBlank(bean.getOrganizeCode())) {
            SqlPack.getStringEqualPack(bean.getOrganizeCode(), "organizeCode", hqlStr);
        }

        // 封装有效状态和删除状态
        SqlPack.getNumEqualPack(bean.getIsValid(), "isValid", hqlStr);
        SqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", hqlStr);

        return hqlStr.toString();
    }

    /**
     * PO订单明细表 分页查询
     *
     * @param wmsPOMasterDetails
     * @return
     */
    public static String packHqlWmsPOMasterDetails(WmsPOMasterDetails wmsPOMasterDetails) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsPOMasterDetails.getOrderNo(), "orderNo", result);
        HqlPack.getStringLikerPack(wmsPOMasterDetails.getItem(), "item", result);
        HqlPack.getStringLikerPack(wmsPOMasterDetails.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsPOMasterDetails.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getStringLikerPack(wmsPOMasterDetails.getZTime(), "zTime", result);
        HqlPack.getStringLikerPack(wmsPOMasterDetails.getZDate(), "zDate", result);

        getStringBuilderPack(wmsPOMasterDetails, result);

        return result.toString();
    }

    /**
     * 库存移动单详情查询封装
     *
     * @param wmsDocMovementDetails
     * @return
     */
    public static String packWmsDocMovementDetails(WmsDocMovementDetails wmsDocMovementDetails) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsDocMovementDetails.getOrderNo(), "orderNo", result);

        getStringBuilderPack(wmsDocMovementDetails, result);

        return result.toString();
    }

    /**
     * 库存移动单查询封装
     *
     * @param wmsDocMovementMaster
     * @return
     */
    public static String packWmsDocMovementMaster(WmsDocMovementMaster wmsDocMovementMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsDocMovementMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsDocMovementMaster.getMoveType(), "moveType", result);
        HqlPack.getNumEqualPack(wmsDocMovementMaster.getBusiType(), "busiType", result);
        HqlPack.getStringLikerPack(wmsDocMovementMaster.getCustomerNo(), "customerNo", result);

        getStringBuilderPack(wmsDocMovementMaster, result);

        return result.toString();
    }

    /**
     * PO订单主表信息 分页查询
     *
     * @param wmsPOMaster
     * @return
     */
    public static String packHqlWmsPOMaster(WmsPOMaster wmsPOMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsPOMaster.getOrderNo(), "orderNo", result);
        HqlPack.getStringLikerPack(wmsPOMaster.getPoType(), "poType", result);
        HqlPack.getNumEqualPack(wmsPOMaster.getPoStatus(), "poStatus", result);
        HqlPack.getStringLikerPack(wmsPOMaster.getVendorNo(), "vendorNo", result);
        HqlPack.getStringLikerPack(wmsPOMaster.getSrc(), "src", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getIsAsn(), "isAsn", result);

        getStringBuilderPack(wmsPOMaster, result);

        return result.toString();
    }

    /**
     * 物流路线子表查询条件封装
     *
     * @param routingCode
     * @return
     */
    public static String packHqlWmsRoutingChildren(String routingCode) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(routingCode, "routingCode", result);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(),
                "isDeleted", result);

        return result.toString();
    }


    /**
     * 物流路线主表查询条件封装
     *
     * @param wmsRoutingMaster
     * @return
     */
    public static String packHqlWmsRoutingMaster(WmsRoutingMaster wmsRoutingMaster) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringLikerPack(wmsRoutingMaster.getRoutingCode(), "routingCode", result);
        HqlPack.getStringLikerPack(wmsRoutingMaster.getRoutingName(), "routingName", result);

        getStringBuilderPack(wmsRoutingMaster, result);

        return result.toString();
    }

    /**
     * 物料查询条件封装
     *
     * @param wmsPart
     * @return
     */
    public static String packHqlWmsPart(WmsPart wmsPart) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(wmsPart.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsPart.getPartName(), "partName", result);
        HqlPack.getStringLikerPack(wmsPart.getPartSpec(), "partSpec", result);
        HqlPack.getStringLikerPack(wmsPart.getPartType(), "partType", result);

        getStringBuilderPack(wmsPart, result);

        return result.toString();
    }

    /**
     * 抽点比例信息 分页查询
     *
     * @param wmsIbCheckPlan
     * @return
     */
    public static String packHqlWmsIbCheckPlan(WmsIbCheckPlan wmsIbCheckPlan) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsIbCheckPlan.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsIbCheckPlan.getPartNameRdd(), "partNameRdd", result);
        HqlPack.timeBuilder(wmsIbCheckPlan.getStartDate(), null, "startDate", result, true);
        HqlPack.timeBuilder(wmsIbCheckPlan.getEndDate(), null, "endDate", result, true);

        getStringBuilderPack(wmsIbCheckPlan, result);

        return result.toString();
    }

    /**
     * 库位物料信息 分页查询
     *
     * @param wmsLocatePart
     * @return
     */
    public static String packHqlWmsLocatePart(WmsLocatePart wmsLocatePart) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsLocatePart.getLocateNo(), "locateNo", result);
        HqlPack.getStringLikerPack(wmsLocatePart.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsLocatePart.getPartNameRdd(), "partNameRdd", result);

        getStringBuilderPack(wmsLocatePart, result);

        return result.toString();
    }

    /**
     * 库位信息 分页查询
     *
     * @param wmsLocate
     * @return
     */
    public static String packHqlWmsLocates(WmsLocate wmsLocate) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsLocate.getLocateNo(), "locateNo", result);
        HqlPack.getStringLikerPack(wmsLocate.getLocateName(), "locateName", result);
        HqlPack.getStringEqualPack(wmsLocate.getLocateType(), "locateType", result);
        HqlPack.getStringLikerPack(wmsLocate.getWhNo(), "whNo", result);
        HqlPack.getStringLikerPack(wmsLocate.getZoneNo(), "zoneNo", result);
        HqlPack.getNumEqualPack(wmsLocate.getIsEmpty(), "isEmpty", result);

        getStringBuilderPack(wmsLocate, result);

        return result.toString();
    }

    /**
     * 交易类型信息 分页查询
     *
     * @param wmsTransType
     * @return
     */
    public static String packHqlWmsTransType(WmsTransType wmsTransType) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsTransType.getTransTypeCode(), "transTypeCode", result);
        HqlPack.getStringLikerPack(wmsTransType.getTransTypeName(), "transTypeName", result);
        HqlPack.getStringLikerPack(wmsTransType.getProgCode(), "progCode", result);

        getStringBuilderPack(wmsTransType, result);

        return result.toString();
    }

    /**
     * 库存交易记录信息 分页查询
     *
     * @param wmsTrans
     * @return
     */
    public static String packHqlWmsTrans(WmsTrans wmsTrans) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsTrans.getTransCode(), "transCode", result);
        HqlPack.getStringEqualPack(wmsTrans.getSn(), "sn", result);
        HqlPack.timeBuilder(wmsTrans.getCreateDatetime(), null, "createDatetime", result, true);

        getStringBuilderPack(wmsTrans, result);

        return result.toString();
    }

    /**
     * 仓库分页查询条件
     *
     * @param wareHouse
     * @return
     */
    public static String packHqlWareHouse(WareHouse wareHouse) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(wareHouse.getAddress(), "address", result);
        HqlPack.getStringLikerPack(wareHouse.getCode(), "code", result);
        HqlPack.getStringLikerPack(wareHouse.getName(), "name", result);

        getStringBuilderPack(wareHouse, result);

        return result.toString();
    }

    /**
     * 供应商分页查询
     *
     * @param basVendor
     * @return
     */
    public static String packHqlBasVendor(BasVendor basVendor) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(basVendor.getVendorNo(), "vendorNo", result);
        HqlPack.getStringLikerPack(basVendor.getVendorName(), "vendorName", result);
        HqlPack.getStringLikerPack(basVendor.getVendorOwner(), "vendorOwner", result);
        HqlPack.getStringLikerPack(basVendor.getVendorDesc(), "vendorDesc", result);
        HqlPack.getStringLikerPack(basVendor.getVendorAddr(), "vendorAddr", result);
        HqlPack.getStringLikerPack(basVendor.getVendorEmail(), "vendorEmail", result);
        HqlPack.getNumEqualPack(basVendor.getIsAsn(), "isAsn", result);

        getStringBuilderPack(basVendor, result);

        return result.toString();
    }

    /**
     * 作业类型分页查询
     *
     * @param wmsOpType
     * @return
     */
    public static String packHqlWmsOpType(WmsOpType wmsOpType) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsOpType.getOpTypeCode(), "opTypeCode", result);
        HqlPack.getStringLikerPack(wmsOpType.getOpTypeName(), "opTypeName", result);
        HqlPack.getStringEqualPack(wmsOpType.getProCode(), "proCode", result);
        HqlPack.getNumEqualPack(wmsOpType.getSeq(), "seq", result);

        getStringBuilderPack(wmsOpType, result);

        return result.toString();
    }

    /**
     * 仓库唯一性校验查询条件【用于添加和修改】
     *
     * @param wareHouse
     * @return
     */
    public static String packHqlWareHouseUnique(WareHouse wareHouse) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wareHouse.getName(), "name", result);
        HqlPack.getStringEqualPack(wareHouse.getCode(), "code", result);
        HqlPack.getNumNOEqualPack(wareHouse.getId(), "id", result);

        getStringBuilderPack(wareHouse, result);

        return result.toString();
    }

    /**
     * 供应商唯一性校验查询条件【用于添加和修改】
     *
     * @param basVendor
     * @return
     */
    public static String packHqlBasVendorUnique(BasVendor basVendor) {
        StringBuffer result = new StringBuffer();

        HqlPack.getNumNOEqualPack(basVendor.getId(), "id", result);
        HqlPack.getStringEqualPack(basVendor.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(basVendor.getVendorName(), "vendorName", result);
        HqlPack.getStringEqualPack(basVendor.getVendorDesc(), "vendorDesc", result);

        getStringBuilderPack(basVendor, result);

        return result.toString();
    }

    public static String packHqlWmsOpTypeUnique(WmsOpType wmsOpType) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsOpType.getOpTypeCode(), "opTypeCode", result);
        HqlPack.getStringLikerPack(wmsOpType.getOpTypeName(), "opTypeName", result);

        getStringBuilderPack(wmsOpType, result);

        return result.toString();
    }

    /**
     * 存储区信息 查询条件封装
     *
     * @param wmsZones
     * @return
     */
    public static String packHqlWmsZones(WmsZones wmsZones) {
        StringBuffer result = new StringBuffer();

        //仓库代码
        HqlPack.getStringEqualPack(wmsZones.getWhNo(), "whNo", result);
        //库存地代码
        HqlPack.getStringEqualPack(wmsZones.getAreaNo(), "areaNo", result);
        //存储区代码
        HqlPack.getStringEqualPack(wmsZones.getZoneNo(), "zoneNo", result);

        getStringBuilderPack(wmsZones, result);

        return result.toString();
    }

    /**
     * 客户信息 查询条件封装
     *
     * @param basCustomer
     * @return
     */
    public static String packHqlBasCustomer(BasCustomer basCustomer) {
        StringBuffer result = new StringBuffer();

        //客户编号
        HqlPack.getStringEqualPack(basCustomer.getCustNo(), "custNo", result);
        //客户简称
        HqlPack.getStringLikerPack(basCustomer.getCustName(), "custName", result);
        //客户全称
        HqlPack.getStringLikerPack(basCustomer.getCustDesc(), "custDesc", result);

        getStringBuilderPack(basCustomer, result);

        return result.toString();
    }

    /**
     * 客户发往地信息 查询条件封装
     *
     * @param wmsShippingFlag
     * @return
     */
    public static String packHqlWmsShippingFlag(WmsShippingFlag wmsShippingFlag) {
        StringBuffer result = new StringBuffer();

        //供应商编号
        HqlPack.getStringEqualPack(wmsShippingFlag.getFlagNo(), "flagNo", result);
        //供应商简称
        HqlPack.getStringLikerPack(wmsShippingFlag.getFlagName(), "flagName", result);
        //供应商全称
        HqlPack.getStringLikerPack(wmsShippingFlag.getFlagDesc(), "flagDesc", result);

        getStringBuilderPack(wmsShippingFlag, result);

        return result.toString();
    }

    /**
     * ASN订单分页查询条件
     *
     * @param wmsASNMaster
     * @return
     */
    public static String packHqlWmsASNMaster(WmsASNMaster wmsASNMaster) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsASNMaster.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getAsnType(), "asnType", result);
        HqlPack.getNumEqualPack(wmsASNMaster.getAsnStatus().toString(), "asnStatus", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getVersion(), "version", result);
        HqlPack.getStringLikerPack(wmsASNMaster.getSrc(), "src", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getPoNo(), "poNo", result);

        getStringBuilderPack(wmsASNMaster,result);

        return result.toString();
    }

    /**
     * 产品发运信息 查询条件封装
     *
     * @param wmsShopping
     * @return
     */
    public static String packHqlWmsShipping(WmsShopping wmsShopping) {
        StringBuffer result = new StringBuffer();

        //发运单号
        HqlPack.getStringEqualPack(wmsShopping.getOrderNo(), "orderNo", result);
        //客户编码
        HqlPack.getStringEqualPack(wmsShopping.getCustNo(), "custNo", result);
        //物料编码
        HqlPack.getStringEqualPack(wmsShopping.getPartNo(), "partNo", result);
        //条码
        HqlPack.getStringEqualPack(wmsShopping.getSn(), "sn", result);
        //发运状态
        HqlPack.getNumEqualPack(wmsShopping.getOrderStatus(), "orderStatus", result);
        //特殊发货标志
        HqlPack.getStringEqualPack(wmsShopping.getShippingFlag(), "shippingFlag", result);

        getStringBuilderPack(wmsShopping, result);

        return result.toString();
    }

    /**
     * 抽点记录信息 查询条件封装
     *
     * @param wmsCheckFactRecord
     * @return
     */
    public static String packHqlWmsCheckFactRecord(WmsCheckFactRecord wmsCheckFactRecord) {
        StringBuffer result = new StringBuffer();

        //采购单号
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getPoNo(), "poNo", result);
        //ASN单号
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getAsnNo(), "asnNo", result);
        //条码
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getSn(), "getSn", result);
        //物料编码
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getPartNo(), "partNo", result);
        //供应商编号
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getVendorNo(), "vendorNo", result);

        getStringBuilderPack(wmsCheckFactRecord, result);

        return result.toString();
    }

    public static String packHqlWmsASNMasterDetails(WmsASNMasterDetails wmsASNMasterDetails) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsASNMasterDetails.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getItem(), "item", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsASNMasterDetails.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getNumEqualPack(wmsASNMasterDetails.getQty(), "qty", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPoItem(), "poItem", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getUnit(), "unit", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getZDate(), "zDate", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getZTime(), "zTime", result);
        HqlPack.getNumEqualPack(wmsASNMasterDetails.getItemStatus(), "itemStatus", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPackAge(), "packAge", result);
        HqlPack.getNumEqualPack(wmsASNMasterDetails.getIsFree(), "isFree", result);
        HqlPack.getStringLikerPack(wmsASNMasterDetails.getDock(), "dock", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getSnOneBarCode(), "snOneBarCode", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getSnTwoBarCode(), "snTwoBarCode", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getGroupNo(), "groupNo", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getErpWhNo(), "erpWhNo", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getVendorLotNo(), "vendorLotNo", result);

        getStringBuilderPack(wmsASNMasterDetails,result);

        return result.toString();
    }

    /**
     * 产品入库信息 条件封装
     *
     * @param wmsFGInStock
     * @return
     */
    public static String packHqlWmsFGInStock(WmsFGInStock wmsFGInStock) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsFGInStock.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getWoNo(), "woNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsFGInStock.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getNumEqualPackDouble(wmsFGInStock.getQty(), "qty", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getUnit(), "unit", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getSn(), "sn", result);
        HqlPack.getNumEqualPack(wmsFGInStock.getOrderStatus(), "orderStatus", result);
        HqlPack.getStringLikerPack(wmsFGInStock.getReMark(), "reMark", result);
        HqlPack.getStringLikerPack(wmsFGInStock.getSrc(), "src", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getErpWhNo(), "erpWhno", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getLineNo(), "lineNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getCustNo(), "custNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getShippingFlag(), "shippingFlag", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getMfgLogNo(), "mfgLogNo", result);

        getStringBuilderPack(wmsFGInStock, result);

        return result.toString();
    }

    /**
     * 作业任务信息条件封装
     *
     * @param wmsTaskInfo
     * @return
     */
    public static String packHqlWmsTaskInfo(WmsTaskInfo wmsTaskInfo) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsTaskInfo.getMoveNo(), "moveNo", result);
        HqlPack.getStringEqualPack(wmsTaskInfo.getUserNo(), "userNo", result);
        HqlPack.getStringEqualPack(wmsTaskInfo.getOpTypeCode(), "opTypeCode", result);
        HqlPack.getStringLikerPack(wmsTaskInfo.getReMark(), "reMark", result);
        HqlPack.getNumEqualPack(wmsTaskInfo.getTaskStatus(), "taskStatus", result);

        getStringBuilderPack(wmsTaskInfo, result);

        return result.toString();
    }

    /**
     * 根据条件查询打印机队列信息封装类
     * @param wmsSnPrint 打印机队列信息
     * @return 打印机队列信息
     */
    public static String packHqlWmsSnPrint(WmsSnPrint wmsSnPrint) {
        StringBuffer result = new StringBuffer();

        // 来源单据类型
        HqlPack.getStringEqualPack(wmsSnPrint.getRefType(), "refType", result);
        // 来源单据号
        HqlPack.getStringEqualPack(wmsSnPrint.getRefNo(), "refNo", result);
        // 打印机
        HqlPack.getStringEqualPack(wmsSnPrint.getPrinter(), "printer", result);
        // 打印机状态
        HqlPack.getNumEqualPack(wmsSnPrint.getPrintStatus(), "printStatus", result);

        getStringBuilderPack(wmsSnPrint, result);

        return result.toString();
    }

    /**
     * 盘点库位 条件封装
     * @param wmsCSLocate
     * @return
     */
    public static String packHqlWmsCSLocate(WmsCSLocate wmsCSLocate){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsCSLocate.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsCSLocate.getLocateNo(), ";locateNo", result);

        getStringBuilderPack(wmsCSLocate, result);

        return result.toString();
    }

    /**
     * 盘点物料 条件封装
     * @param wmsCSPart
     * @return
     */
    public static String packHqlWmsCSPart(WmsCSPart wmsCSPart){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsCSPart.getOrderNo(),"orderNo", result);
        HqlPack.getStringEqualPack(wmsCSPart.getPartNo(),"partNo", result);
        HqlPack.getStringLikerPack(wmsCSPart.getPartNameRdd(),"partNameRdd", result);

        getStringBuilderPack(wmsCSPart, result);

        return result.toString();
    }

    /**
     * 盘点存储区 条件封装
     * @param wmsCSZone
     * @return
     */
    public static String packHqlWmsCSZone(WmsCSZone wmsCSZone){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsCSZone.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsCSZone.getZoneNo(), "zoneNo", result);

        getStringBuilderPack(wmsCSZone, result);

        return result.toString();
    }

    /**
     * 根据条件查询责任区分配信息封装类
     * @param wmsAreaOwner 责任区分配信息
     * @return 责任区分配信息
     */
    public static String packHqlWmsAreaOwner(WmsAreaOwner wmsAreaOwner) {
        StringBuffer result = new StringBuffer();

        // 仓库代码
        HqlPack.getStringEqualPack(wmsAreaOwner.getWhNo(), "whNo", result);
        // 来源单据号
        HqlPack.getStringEqualPack(wmsAreaOwner.getZoneNo(), "zoneNo", result);
        // 供应商编码
        HqlPack.getStringEqualPack(wmsAreaOwner.getVendorNo(), "vendorNo", result);
        // 物料编码
        HqlPack.getStringEqualPack(wmsAreaOwner.getPartNo(), "partNo", result);
        // 负责人
        HqlPack.getStringEqualPack(wmsAreaOwner.getOwnerUserNo(), "ownerUserNo", result);
        // 是否预分配
        HqlPack.getNumEqualPack(wmsAreaOwner.getIsPreAssign(), "isPreAssign", result);

        getStringBuilderPack(wmsAreaOwner, result);

        return result.toString();
    }

    /**
     * 根据条件查询责任区分配信息封装类
     * @param wmsTempOrderLock 责任区分配信息
     * @return 责任区分配信息
     */
    public static String packHqlWmsTempOrderLock(WmsTempOrderLock wmsTempOrderLock) {
        StringBuffer result = new StringBuffer();

        // 订单号
        HqlPack.getStringEqualPack(wmsTempOrderLock.getOrderNo(), "orderNo", result);
        // 业务类型
        HqlPack.getStringEqualPack(wmsTempOrderLock.getBizType(), "bizType", result);

        getStringBuilderPack(wmsTempOrderLock, result);

        return result.toString();
    }

    /**
     * 业务：库存条码查询封装
     *
     * @param wmsStockSn
     * @return
     */
    public static String packWmsStockSn(WmsStockSn wmsStockSn) {
        StringBuffer result = new StringBuffer();
        //查询参数封装
        HqlPack.getStringEqualPack(wmsStockSn.getLocateNo(), "locateNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getPartNo(), "partNo", result);

        getStringBuilderPack(wmsStockSn, result);

        return result.toString();
    }

    /**
     * 业务：库存查询封装
     *
     * @param wmsStockQuan
     * @return
     */
    public static String packWmsStockQuan(WmsStockQuan wmsStockQuan) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsStockQuan.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getZoneNo(), "zoneNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getLocateNo(), "locateNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getPartNo(), "partNo", result);

        getStringBuilderPack(wmsStockQuan, result);

        return result.toString();
    }

    /**
     * 业务：库存交易条码查询封装(根据交易编码查询所有未删除的)
     *
     * @param tranNo
     * @return
     */
    public static String packWmsTransSn(Long tranNo) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getNumEqualPack(tranNo, "transNo", result);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", result);

        return result.toString();
    }

    /**
     * 业务：库存交易查询封装
     *
     * @param wmsTransQuan
     * @return
     */
    public static String packWmsTransQuan(WmsTransQuan wmsTransQuan) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsTransQuan.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsTransQuan.getZoneNo(), "zoneNo", result);
        HqlPack.getStringEqualPack(wmsTransQuan.getPartNo(), "partNo", result);
        HqlPack.getStringEqualPack(wmsTransQuan.getLocateNo(), "locateNo", result);

        getStringBuilderPack(wmsTransQuan, result);

        return result.toString();
    }

    /**
     * 业务：物料包装查询封装
     *
     * @param wmsPackage
     * @return
     */
    public static String packWmsPackAge(WmsPackage wmsPackage) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsPackage.getPackageNo(), "packageNo", result);
        HqlPack.getStringEqualPack(wmsPackage.getParentPackageNo(), "parentPackageNo", result);
        HqlPack.getStringEqualPack(wmsPackage.getSn(), "sn", result);
        HqlPack.getNumEqualPack(wmsPackage.getPackTypeId(), "packTypeId", result);

        getStringBuilderPack(wmsPackage, result);

        return result.toString();
    }
    /**
     *内部单据：库存移动单主表唯一性查询
     * @param wmsMoveMaster
     * @return
     */
    public static String packWmsMoveMasterUnique(WmsMoveMaster wmsMoveMaster){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumNOEqualPack(wmsMoveMaster.getId(),"id",result);

        getStringBuilderPack(wmsMoveMaster, result);

        return result.toString();
    }

    /**
     * 内部单据：库存移动单主表分页查询
     * @param wmsMoveMaster
     * @return
     */
    public static String packHqlWmsMoveMaster(WmsMoveMaster wmsMoveMaster){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsMoveMaster.getOrderStatus(),"orderStatus",result);

        getStringBuilderPack(wmsMoveMaster, result);

        return result.toString();
    }

    /**
     * 内部单据：库存移动单明细表分页查询
     * @param wmsMoveDetails
     * @return
     */
    public static String packHqlWmsMoveDetails(WmsMoveDetails wmsMoveDetails){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveDetails.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsMoveDetails.getItem(), "item", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsMoveDetails.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getCustNo(), "custNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getUnit(), "unit", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getWhNo(),"whNo",result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getZoneNo(),"zoneNo",result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getLocateNo(),"locateNo",result);
        HqlPack.getNumEqualPack(wmsMoveDetails.getItemStatus(),"itemStatus",result);
        HqlPack.getNumEqualPack(wmsMoveDetails.getRefType(),"refType",result);
        HqlPack.getStringLikerPack(wmsMoveDetails.getRefSrc(),"refSrc",result);

        getStringBuilderPack(wmsMoveDetails, result);

        return result.toString();
    }

    /**
     * 内部单据：库存移动单条码信息分页查询
     * @param wmsMoveSn
     * @return
     */
    public static String packHqlWmsMoveSn(WmsMoveSn wmsMoveSn){
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveSn.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsMoveSn.getItem(), "item", result);
        HqlPack.getStringEqualPack(wmsMoveSn.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsMoveSn.getPartNameRdd(), "partNameRdd", result);

        getStringBuilderPack(wmsMoveSn, result);

        return result.toString();
    }

    /**
     * 质检单信息 查询条件封装
     *
     * @param wmsQCMaster
     * @return
     */
    public static String packHqlWmsQCMaster(WmsQCMaster wmsQCMaster) {
        StringBuffer result = new StringBuffer();

        //单号
        HqlPack.getStringEqualPack(wmsQCMaster.getOrderNo(), "orderNo", result);
        //业务类型
        HqlPack.getNumEqualPack(wmsQCMaster.getOrderType(), "orderType", result);
        //采购单号
        HqlPack.getStringEqualPack(wmsQCMaster.getPoNo(), "poNo", result);
        //ASN单号
        HqlPack.getStringEqualPack(wmsQCMaster.getAsnNo(), "asnNo", result);
        //入库单号
        HqlPack.getStringEqualPack(wmsQCMaster.getIbNo(), "ibNo", result);

        getStringBuilderPack(wmsQCMaster, result);

        return result.toString();
    }

    /**
     * 质检单明细信息 查询条件封装
     *
     * @param wmsQCDetails
     * @return
     */
    public static String packHqlWmsQCDetails(WmsQCDetails wmsQCDetails) {
        StringBuffer result = new StringBuffer();

        //单号
        HqlPack.getStringEqualPack(wmsQCDetails.getOrderNo(), "orderNo", result);

        getStringBuilderPack(wmsQCDetails, result);

        return result.toString();
    }

    /**
     * 质检单操作明细信息 查询条件封装
     *
     * @param wmsQCTrans
     * @return
     */
    public static String packHqlWmsQCTrans(WmsQCTrans wmsQCTrans) {
        StringBuffer result = new StringBuffer();

        //单号
        HqlPack.getStringEqualPack(wmsQCTrans.getOrderNo(), "orderNo", result);
        //行号
        HqlPack.getStringEqualPack(wmsQCTrans.getItem(), "item", result);

        getStringBuilderPack(wmsQCTrans, result);

        return result.toString();
    }

    /**
     * 盘点单主表信息 分页查询
     *
     * @param wmsCSOrderMaster
     * @return
     */
    public static String packHqlWmsCSOrderMasters(WmsCSOrderMaster wmsCSOrderMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsCSOrderMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsCSOrderMaster.getOrderType(), "orderType", result);
        HqlPack.getNumEqualPack(wmsCSOrderMaster.getOrderStatus(), "orderStatus", result);

        getStringBuilderPack(wmsCSOrderMaster, result);

        return result.toString();
    }

    /**
     * 盘点单冻结表信息 分页查询
     *
     * @param wmsCSOrderDetails
     * @return
     */
    public static String packHqlWmsCSOrderDetails(WmsCSOrderDetails wmsCSOrderDetails) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsCSOrderDetails.getOrderNo(), "orderNo", result);

        getStringBuilderPack(wmsCSOrderDetails, result);

        return result.toString();
    }

    /**
     * 盘点实盘表信息 分页查询
     *
     * @param wmsCSFactTrans
     * @return
     */
    public static String packHqlWmsCSFactTrans(WmsCSFactTrans wmsCSFactTrans) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsCSFactTrans.getOrderNo(), "orderNo", result);

        getStringBuilderPack(wmsCSFactTrans, result);

        return result.toString();
    }

    /**
     * 作业步骤 查询
     *
     * @param wmsActionStepCall
     * @return
     */
    public static String packHqlWmsActionStepCall(WmsActionStepCall wmsActionStepCall) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getNumEqualPack(wmsActionStepCall.getAsId(), "asId", result);
        HqlPack.getNumEqualPack(wmsActionStepCall.getAmId(), "amId", result);

        getStringBuilderPack(wmsActionStepCall, result);

        return result.toString();
    }

    /**
     * 作业步骤类型表信息查询
     *
     * @param wmsActionStepType
     * @return
     */
    public static String packHqlWmsActionStepType(WmsActionStepType wmsActionStepType) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsActionStepType.getAtNameC(), "atNameC", result);

        getStringBuilderPack(wmsActionStepType, result);

        return result.toString();
    }

    /**
     * 作业步骤信息查询
     *
     * @param wmsActionStep
     * @return
     */
    public static String packHqlWmsActionStep(WmsActionStep wmsActionStep) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsActionStep.getAsNameC(), "asNameC", result);

        getStringBuilderPack(wmsActionStep, result);

        return result.toString();
    }
}
